package com.fuyuanshen.modules.system.domain;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.bean.copier.CopyOptions;
import com.baomidou.mybatisplus.annotation.IdType;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableId;
import com.baomidou.mybatisplus.annotation.TableName;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;
import com.fuyuanshen.base.BaseEntity;

import javax.validation.constraints.NotBlank;
import java.io.Serializable;

/**
 * @Description: 设备表
 * @Author: WY
 * @Date: 2025/5/16
 **/
@Data
@TableName("device")
@JsonInclude(JsonInclude.Include.ALWAYS) // 关键注解
public class Device extends BaseEntity implements Serializable {

    @TableId(value = "id", type = IdType.AUTO)
    @ApiModelProperty(value = "ID")
    private Long id;

    @ApiModelProperty(value = "设备记录ID")
    @TableField(exist = false)
    private Long assignId;

    @ApiModelProperty(value = "设备类型")
    private Long deviceType;

    @ApiModelProperty(value = "设备类型名称")
    private String typeName;

    @ApiModelProperty(value = "客户号")
    private Long customerId;

    /**
     * 当前所有者
     * current_owner_id
     */
    @ApiModelProperty(value = "当前所有者")
    private Long currentOwnerId;

    /**
     * 原始所有者（创建者）
     * original_owner_id
     */
    @ApiModelProperty(value = "原始所有者（创建者）")
    private Long originalOwnerId;

    @ApiModelProperty(value = "所属客户")
    private String customerName;

    /*@ApiModelProperty(value = "设备编号")
    private String deviceNo;*/

    @ApiModelProperty(value = "设备名称")
    private String deviceName;

    @ApiModelProperty(value = "设备图片")
    private String devicePic;

    @ApiModelProperty(value = "设备MAC")
    private String deviceMac;

    @ApiModelProperty(value = "设备IMEI")
    private String deviceImei;

    @ApiModelProperty(value = "设备SN")
    private String deviceSn;

    @ApiModelProperty(value = "经度")
    private String longitude;

    @ApiModelProperty(value = "纬度")
    private String latitude;

    @ApiModelProperty(value = "备注")
    private String remark;

    /**
     * 租户ID
     */
    @TableField(value = "tenant_id")
    @ApiModelProperty(hidden = true)
    private Long tenantId;

    /**
     * 设备状态
     * 0 失效
     * 1 正常
     */
    @ApiModelProperty(value = "设备状态")
    private Integer deviceStatus;

    /**
     * 绑定状态
     * 0 未绑定
     * 1 已绑定
     */
    @ApiModelProperty(value = "绑定状态")
    private Integer bindingStatus;


    public void copy(Device source) {
        BeanUtil.copyProperties(source, this, CopyOptions.create().setIgnoreNullValue(true));
    }

}
