// package com.fuyuanshen.modules.system.listener.excel;
//
// import cn.hutool.core.bean.BeanUtil;
// import com.alibaba.excel.context.AnalysisContext;
// import com.alibaba.excel.read.listener.ReadListener;
// import com.alibaba.fastjson.JSON;
// import lombok.extern.slf4j.Slf4j;
// import com.fuyuanshen.constants.DeviceConstants;
// import com.fuyuanshen.modules.system.domain.Device;
// import com.fuyuanshen.modules.system.domain.dto.DeviceExcelImportDTO;
// import com.fuyuanshen.modules.system.service.DeviceService;
// import org.apache.poi.openxml4j.opc.OPCPackage;
// import org.apache.poi.openxml4j.util.ZipSecureFile;
// import org.apache.poi.xssf.usermodel.*;
// import org.springframework.web.multipart.MultipartFile;
//
// import java.io.File;
// import java.nio.file.Files;
// import java.util.ArrayList;
// import java.util.HashMap;
// import java.util.List;
// import java.util.Map;
//
// @Slf4j
// public class UploadDeviceDataListener2 implements ReadListener<DeviceExcelImportDTO> {
//
//     private final DeviceService deviceService;
//     private final MultipartFile file;
//     private final String filePath;
//     private final List<Device> allDevices = new ArrayList<>(); // 存储所有设备对象
//     private final Map<Integer, Device> rowDeviceMap = new HashMap<>(); // 行索引到设备的映射
//
//
//     public UploadDeviceDataListener2(DeviceService deviceService, MultipartFile file, String filePath) {
//         this.deviceService = deviceService;
//         this.file = file;
//         this.filePath = filePath;
//     }
//
//
//     private int successCount = 0;
//     private int failureCount = 0;
//     private final List<DeviceExcelImportDTO> failedRecords = new ArrayList<>();
//
//     public int getSuccessCount() {
//         return successCount;
//     }
//
//     public int getFailureCount() {
//         return failureCount;
//     }
//
//     public List<DeviceExcelImportDTO> getFailedRecords() {
//         return failedRecords;
//     }
//
//
//     @Override
//     public void invoke(DeviceExcelImportDTO data, AnalysisContext context) {
//         log.info("解析到一条数据: {}", JSON.toJSONString(data));
//
//         // 创建设备对象并存储
//         Device device = new Device();
//         BeanUtil.copyProperties(data, device, true);
//         int rowIndex = context.readRowHolder().getRowIndex(); // 获取当前行索引
//         allDevices.add(device);
//         rowDeviceMap.put(rowIndex, device); // 建立行索引映射
//     }
//
//
//     @Override
//     public void doAfterAllAnalysed(AnalysisContext context) {
//         try {
//             // 处理图片并设置URL
//             processImages();
//             // 批量插入数据（此时已包含图片URL）
//             saveAllData();
//             log.info("所有数据解析完成并已入库！");
//         } catch (Exception e) {
//             log.error("数据处理失败：{}", e.getMessage(), e);
//             throw new RuntimeException("导入失败", e);
//         }
//     }
//
//     private void processImages() {
//         try (OPCPackage opcPackage = OPCPackage.open(file.getInputStream())) {
//             ZipSecureFile.setMinInflateRatio(-1.0d);
//             XSSFWorkbook workbook = new XSSFWorkbook(opcPackage);
//             XSSFSheet sheet = workbook.getSheetAt(0); // 假设数据在第一个Sheet
//
//             XSSFDrawing drawing = sheet.getDrawingPatriarch();
//             if (drawing == null) return;
//
//             // 处理所有图片
//             for (XSSFShape shape : drawing.getShapes()) {
//                 if (shape instanceof XSSFPicture) {
//                     XSSFPicture picture = (XSSFPicture) shape;
//                     XSSFClientAnchor anchor = picture.getPreferredSize();
//                     int rowIndex = anchor.getRow1(); // 图片所在行
//                     int colIndex = anchor.getCol1(); // 图片所在列
//
//                     // 检查是否为设备图片列（第4列）
//                     if (colIndex == 3) {
//                         Device device = rowDeviceMap.get(rowIndex);
//                         if (device != null) {
//                             byte[] imageData = picture.getPictureData().getData();
//                             String extraValue = getCellValue(sheet, rowIndex, 4); // 获取第5列的值
//                             String imageUrl = uploadAndGenerateUrl(imageData, extraValue);
//                             device.setDevicePic(imageUrl); // 直接设置URL
//                         }
//                     }
//                 }
//             }
//         } catch (Exception e) {
//             log.error("图片处理失败：{}", e.getMessage(), e);
//             throw new RuntimeException("图片处理异常", e);
//         }
//     }
//
//     private String getCellValue(XSSFSheet sheet, int rowIndex, int colIndex) {
//         XSSFRow row = sheet.getRow(rowIndex);
//         if (row == null) return null;
//
//         XSSFCell cell = row.getCell(colIndex);
//         if (cell == null) return null;
//
//         return cell.toString(); // 可以根据需要做更复杂的解析
//     }
//
//     private void saveAllData() {
//         if (!allDevices.isEmpty()) {
//             log.info("共{}条数据，开始批量入库", allDevices.size());
//             deviceService.saveBatch(allDevices);
//             log.info("数据入库成功");
//         }
//     }
//
//     private String uploadAndGenerateUrl(byte[] imageData, String deviceMac) {
//         if (imageData == null || imageData.length == 0) {
//             log.warn("图片数据为空");
//             return null;
//         }
//
//         try {
//             // 构建新文件名
//             String fileExtension = "jpg"; // 假设图片为 jpg 格式，也可以根据实际格式判断
//             String newFileName = "PS_" + deviceMac + "." + fileExtension;
//
//             // 拼接文件路径（假设 filePath 是一个基础路径）
//             String targetDirPath = filePath + DeviceConstants.FILE_ACCESS_ISOLATION;
//             File targetDir = new File(targetDirPath);
//
//             if (!targetDir.exists()) {
//                 boolean created = targetDir.mkdirs();
//                 if (!created) {
//                     log.error("无法创建目录: {}", targetDirPath);
//                     return null;
//                 }
//             }
//
//             File newFile = new File(targetDir, newFileName);
//
//             // 将 byte[] 写入文件
//             Files.write(newFile.toPath(), imageData);
//
//             log.info("图片已保存至: {}", newFile.getAbsolutePath());
//
//             // 返回访问URL（根据你的业务拼接）
//             return ip + DeviceConstants.FILE_ACCESS_PREFIX + "/" + DeviceConstants.FILE_ACCESS_ISOLATION + "/" + newFileName;
//
//         } catch (Exception e) {
//             log.error("保存图片失败", e);
//             return null;
//         }
//     }
//
// }