/*
 *  Copyright 2019-2025 Zheng Jie
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package com.fuyuanshen.modules.system.mapper;

import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.fuyuanshen.modules.system.domain.User;
import com.fuyuanshen.modules.system.domain.dto.UserQueryCriteria;
import com.fuyuanshen.modules.system.domain.query.UserQuery;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;
import org.apache.ibatis.annotations.Select;

import java.util.Date;
import java.util.List;
import java.util.Set;

/**
 * @author Zheng Jie
 * @date 2023-06-20
 */
@Mapper
public interface UserMapper extends BaseMapper<User> {

    Long countAll(@Param("criteria") UserQueryCriteria criteria);

    List<User> findAll(@Param("criteria") UserQueryCriteria criteria);

    /**
     * 根据条件查询 用户
     *
     * @param userQuery
     * @return
     */
    List<User> selectByQuery(@Param("userQuery") UserQuery userQuery);

    /**
     * 根据条件查询一个用户
     *
     * @param userQuery
     * @return
     */
    User selectByQueryOne(@Param("userQuery") UserQuery userQuery);

    /**
     * 分页查询客户
     *
     * @param criteria
     * @return
     */
    List<User> findCustomers(@Param("criteria") UserQueryCriteria criteria);

    /**
     * 获取分页总数
     *
     * @param criteria
     * @return
     */
    Long countCustomers(@Param("criteria") UserQueryCriteria criteria);

    /**
     * 查询所有客户
     *
     * @param criteria
     * @return
     */
    List<User> queryAllCustomers(@Param("criteria") UserQueryCriteria criteria);

    IPage<User> findAll(@Param("criteria") UserQueryCriteria criteria, Page<Object> page);

    /**
     * 根据租户ID查询用户
     *
     * @param tenantId
     * @return
     */
    List<User> findByTenantId(Long tenantId);

    User findByUsername(@Param("username") String username);

    User findByNickName(@Param("nickName") String nickName);

    User findByEmail(@Param("email") String email);

    User findByPhone(@Param("phone") Long phone);

    @Select("update sys_user set password = #{password} , pwd_reset_time = #{lastPasswordResetTime} where username = #{username}")
    void updatePass(@Param("username") String username, @Param("password") String password, @Param("lastPasswordResetTime") Date lastPasswordResetTime);

    @Select("update sys_user set email = #{email} where username = #{username}")
    void updateEmail(@Param("username") String username, @Param("email") String email);

    List<User> findByRoleId(@Param("roleId") Long roleId);

    List<User> findByRoleDeptId(@Param("deptId") Long deptId);

    List<User> findByMenuId(@Param("menuId") Long menuId);

    int countByJobs(@Param("jobIds") Set<Long> jobIds);

    int countByDepts(@Param("deptIds") Set<Long> deptIds);

    int countByRoles(@Param("roleIds") Set<Long> roleIds);

    void resetPwd(@Param("userIds") Set<Long> userIds, @Param("pwd") String pwd);

    /**
     * 获取当前用户以及子用户
     *
     * @param currentUserId
     * @return
     */
    List<User> getSubUsers(Long currentUserId);

    /**
     * 获取当前用户的子用户
     *
     * @param currentUserId
     * @return
     */
    List<User> findUserTree(Long currentUserId);


    List<User> findCustomers1(UserQueryCriteria criteria);

    List<User> findUsersWithAncestorsByIds(@Param("ids") Set<Long> ids);

    /**
     * 获取当前用户的祖先用户
     *
     * @param currentUserId
     * @return
     */
    List<User> findAncestorsById(@Param("currentUserId") Long currentUserId);


}
