package com.fuyuanshen.modules.system.rest.app;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.fuyuanshen.modules.system.domain.app.APPDevice;
import com.fuyuanshen.modules.system.domain.app.APPDeviceType;
import com.fuyuanshen.modules.system.domain.dto.DeviceQueryCriteria;
import com.fuyuanshen.modules.system.domain.dto.app.APPUnbindDTO;
import com.fuyuanshen.modules.system.service.app.APPDeviceService;
import com.fuyuanshen.modules.utils.ResponseVO;
import com.fuyuanshen.utils.PageResult;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * @Description:
 * @Author: WY
 * @Date: 2025/5/16
 **/
@Slf4j
@Api(tags = "APP用户设备管理")
@RestController
@RequiredArgsConstructor
@RequestMapping("/api/app/device")
public class APPDeviceController {

    private final APPDeviceService appDeviceService;


    @PostMapping(value = "/list")
    @ApiOperation("APP用户设备列表")
    public ResponseVO<PageResult<APPDevice>> appDeviceList(@RequestBody DeviceQueryCriteria criteria) {
        Page<APPDevice> page = new Page<>(criteria.getPage(), criteria.getSize());
        PageResult<APPDevice> devices = null;
        try {
            devices = appDeviceService.appDeviceList(page, criteria);
        } catch (Exception e) {
            log.error("queryDevice error: " + e.getMessage());
            return ResponseVO.fail("");
        }
        return ResponseVO.success(devices);
    }


    @PostMapping(value = "/typeList")
    @ApiOperation("APP用户设备类型列表")
    public ResponseVO<List<APPDeviceType>> appTypeList(@RequestBody DeviceQueryCriteria criteria) {
        List<APPDeviceType> typeList = appDeviceService.appTypeList(criteria);
        return ResponseVO.success(typeList);
    }


    @PostMapping(value = "/bind")
    @ApiOperation("APP用户设备绑定")
    public ResponseVO<String> appBindDevice(@RequestBody DeviceQueryCriteria criteria) {
        appDeviceService.appBindDevice(criteria);
        return ResponseVO.success("绑定成功！");
    }


    @GetMapping
    @ApiOperation("WEB端查看APP用户设备绑定")
    public ResponseVO<PageResult<APPDevice>> queryAPPDevice(DeviceQueryCriteria criteria) {
        Page<APPDevice> page = new Page<>(criteria.getPage(), criteria.getSize());
        PageResult<APPDevice> devices = null;
        try {
            devices = appDeviceService.queryAll(page, criteria);
        } catch (Exception e) {
            log.error("queryDevice error: " + e.getMessage());
            return ResponseVO.fail("");
        }
        return ResponseVO.success(devices);
    }


    @PostMapping(value = "/unbind")
    @ApiOperation("WEB端APP用户设备解绑")
    public ResponseVO<String> unbindAPPDevice(@Validated @ModelAttribute APPUnbindDTO deviceForm) {
        appDeviceService.unbindAPPDevice(deviceForm);
        return ResponseVO.success("解绑成功！！！");
    }


}
