package com.fuyuanshen.modules.system.service;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.IService;
import com.fuyuanshen.modules.system.domain.Device;
import com.fuyuanshen.modules.system.domain.dto.CustomerVo;
import com.fuyuanshen.modules.system.domain.dto.DeviceForm;
import com.fuyuanshen.modules.system.domain.dto.DeviceQueryCriteria;
import com.fuyuanshen.utils.PageResult;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.multipart.MultipartFile;

import javax.servlet.http.HttpServletResponse;
import java.io.FileNotFoundException;
import java.io.IOException;
import java.util.List;

/**
 * @Description:
 * @Author: WY
 * @Date: 2025/5/16
 **/
public interface DeviceService extends IService<Device> {

    /**
     * 查询设备数据分页
     *
     * @param criteria 条件
     * @param page     分页参数
     * @return PageResult
     */
    PageResult<Device> queryAll(DeviceQueryCriteria criteria, Page<Object> page) throws IOException;

    /**
     * 查询所有数据不分页
     *
     * @param criteria 条件参数
     * @return List<DeviceDto>
     */
    List<Device> queryAll(DeviceQueryCriteria criteria);

    /**
     * 查询所有设备信息
     *
     * @param criteria
     * @return
     */
    List<Device> queryAllDevices(DeviceQueryCriteria criteria);

    /**
     * 创建
     *
     * @param resources /
     */
    void create(Device resources);

    /**
     * 新增设备
     *
     * @param resources
     */
    void addDevice(DeviceForm resources) throws Exception;

    /**
     * 编辑
     *
     * @param resources /
     */
    void update(DeviceForm resources) throws Exception;

    /**
     * 分配客户
     */
    void assignCustomer(CustomerVo customerVo);

    /**
     * 多选删除
     *
     * @param ids /
     */
    void deleteAll(List<Long> ids);

    /**
     * 删除设备分配记录
     *
     * @param ids
     */
    void deleteAssign(List<Long> ids);

    /**
     * 导出数据
     *
     * @param all      待导出的数据
     * @param response /
     * @throws IOException /
     */
    void download(List<Device> all, HttpServletResponse response) throws IOException;

    /**
     * 导入设备数据
     *
     * @param file
     */
    void importData(MultipartFile file) throws IOException;

    /**
     * 解绑设备
     *
     * @param deviceForm
     */
    void unbindDevice(DeviceForm deviceForm);


}
