/*
 *  Copyright 2019-2025 Zheng Jie
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package com.fuyuanshen.modules.system.service.app;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.IService;
import com.fuyuanshen.modules.security.service.dto.app.AppRoleDto;
import com.fuyuanshen.modules.system.domain.Role;
import com.fuyuanshen.modules.system.domain.app.APPUser;
import com.fuyuanshen.modules.system.domain.dto.UserQueryCriteria;
import com.fuyuanshen.modules.system.domain.dto.app.APPForgotPasswordDTO;
import com.fuyuanshen.modules.system.domain.dto.app.APPUpdateUserDTO;
import com.fuyuanshen.modules.system.domain.dto.app.APPUserDTO;
import com.fuyuanshen.modules.utils.ResponseVO;
import com.fuyuanshen.utils.PageResult;

import java.util.Set;

/**
 * @author Zheng Jie
 * @date 2018-11-23
 */
public interface APPUserService extends IService<APPUser> {

    /**
     * 查询APP/小程序用户
     *
     * @param criteria
     * @param page
     * @return
     */
    PageResult<APPUser> queryAPPUser(UserQueryCriteria criteria, Page<APPUser> page);

    /**
     * 根据用户名查询
     *
     * @param userName /
     * @return /
     */
    APPUser getLoginData(String userName);


    ResponseVO<Object> addUser(APPUserDTO user);

    Integer selectRoleByUserLevel(Set<Role> roles);

    void forgotPassword(APPForgotPasswordDTO appForgotPasswordDTO);

    void sendSms(String phoneNumber);

    void updateUser(APPUpdateUserDTO appUser);
}
