package com.fuyuanshen.modules.utils;

import com.fuyuanshen.constants.ExceptionMessages;
import com.fuyuanshen.exception.BadRequestException;
import com.fuyuanshen.modules.system.constant.UserConstants;
import com.fuyuanshen.modules.system.domain.User;
import com.fuyuanshen.modules.system.service.UserService;
import com.fuyuanshen.utils.SecurityUtils;

/**
 * @author: 默苍璃
 * @date: 2025-06-2110:35
 */

public class AdminCheckUtil {

    /**
     * 检查当前用户是否为超级管理员，如果是则抛出异常，防止误操作
     *
     * @param userService UserService 用于获取当前用户信息
     */
    public static void preventAdminMisoperation(UserService userService) {
        User currentUser = userService.findById(SecurityUtils.getCurrentUserId());
        if (currentUser.getTenantId().equals(UserConstants.SUPER_ADMIN_ID)) {
            throw new BadRequestException(ExceptionMessages.ADMIN_OPERATION_NOT_ALLOWED);
        }
    }

    /**
     * 检查用户是否是超级管理员，如果是则抛出异常
     *
     * @param user 当前用户对象
     */
    public static void checkIfSuperAdmin(User user) {
        if (user.getTenantId().equals(UserConstants.SUPER_ADMIN_ID)) {
            throw new BadRequestException(ExceptionMessages.ADMIN_OPERATION_NOT_ALLOWED);
        }
    }

}